import { Request } from 'express';
import OAuth2Strategy = require('passport-oauth2');
/**
 * `YahooOauthTokenStrategy` constructor.
 *
 * The Yahoo authentication strategy authenticates requests by delegating to
 * Yahoo using the OAuth 2.0 protocol.
 *
 * Applications must supply a `verify` callback which accepts an `accessToken`,
 * `refreshToken` and service-specific `profile`, and then calls the `cb`
 * callback supplying a `user`, which should be set to `false` if the
 * credentials are not valid.  If an exception occurred, `err` should be set.
 *
 * @param {Object} options
 * @param {Function} verify
 * @example
 * passport.use(new YahooOauthTokenStrategy(
 *   {
 *     clientID: '123456789',
 *     clientSecret: 'abcxyz',
 *   },
 *   (accessToken, refreshToken, profile, cb) => {
 *     User.findOrCreate({ yahooId: profile.id }, cb);
 *   }
 * );
 */
type TStrategyOptions = OAuth2Strategy.StrategyOptions;
type TConstructorOptions = Pick<TStrategyOptions, 'clientID' | 'clientSecret'> & Partial<Omit<TStrategyOptions, 'clientID' | 'clientSecret'>> & {
    profileURL?: string;
    accessTokenField?: string;
    refreshTokenField?: string;
    accessCodeField?: string;
};
type TYahooProfile = {
    birthdate?: string;
    email: string;
    email_verified?: boolean;
    family_name?: string;
    gender?: string;
    given_name?: string;
    locale?: string;
    name: string;
    nickname?: string;
    picture?: string;
    profile_images?: {
        [size: string]: string;
    };
    sub: string;
};
type TParsedProfile = TYahooProfile & {
    provider: string;
    id: string;
    photos?: {
        type: string;
        value: string;
    }[];
    _json: any;
    _raw?: any;
};
export default class YahooOauthTokenStrategy extends OAuth2Strategy {
    [x: string]: any;
    private _profileURL;
    private _accessTokenField;
    private _refreshTokenField;
    private _accessCodeField;
    private _passReqToCallback;
    constructor(options: TConstructorOptions, verify: OAuth2Strategy.VerifyFunction);
    /**
     * Authenticate request by delegating to a service provider using OAuth 2.0.
     * @param {Object} req
     * @param {Object} _options
     */
    authenticate(req: Request, _options: unknown): void;
    private _returnUserProfile;
    /**
     * Retrieve user profile from Yahoo.
     *
     * This function constructs a normalized profile, with the following properties:
     *
     *   - `provider`         always set to `yahoo`
     *   - `id`               the user's Yahoo ID
     *   - `username`         the user's Yahoo username
     *   - `name`      the user's full name
     *
     * @param {String} accessToken
     * @param {Function} done
     */
    userProfile(accessToken: string, done: (error: Error | null | undefined, profile?: TParsedProfile | undefined) => void): void;
    /**
     * This method handles searhing the value of provided field in body, query, and header.
     *
     * @param {Object} req http request object
     * @param {String} field
     * @returns {String} field's value in body, query, or headers
     */
    lookup(req: Request, field: string): string;
    /**
     * Parse profile.
     *
     * Parses user profiles as fetched from Yahoo's OpenID Connect-compatible user
     * info endpoint.
     *
     * The amount of detail in the profile varies based on the scopes granted by the
     * user. The following scope values add additional data:
     *
     *     `profile` - basic profile information
     *     `email` - email address
     *
     * References:
     *   - https://developer.yahoo.com/sign-in-with-yahoo/#node-step-four
     *
     * @param {object} json
     * @return {TParsedProfile}
     */
    static parseProfile(json: TYahooProfile): TParsedProfile;
}
export {};
